@@ -17,11 +17,14 @@ void tty_close(tty_t *tty);
 void tty_init(tty_t *tty, const char *tty_filename);
 void tty_getwinsz(tty_t *tty);
 char tty_getchar(tty_t *tty);
-int tty_input_ready(tty_t *tty);
+int tty_input_ready(tty_t *tty, long int timeout, int return_on_signal);
 
 void tty_setfg(tty_t *tty, int fg);
 void tty_setinvert(tty_t *tty);
+void tty_setunderline(tty_t *tty);
 void tty_setnormal(tty_t *tty);
+void tty_setnowrap(tty_t *tty);
+void tty_setwrap(tty_t *tty);
 
 #define TTY_COLOR_BLACK 0
 #define TTY_COLOR_RED 1
